'use strict';
import { AtajoXApi, atajoXApi } from './api';
import { atajoXSocket } from "../socket/socket";
import { atajoXConfig } from "../config/config";
describe('Api', function () {
    it('should create a class', function () {
        expect(atajoXApi).toBeDefined();
    });
    it('should be able to add a transaction to queue', function (done) {
        atajoXApi.addTransaction('fakeTransaction', {}, { queue: true }).subscribe(function (result) {
            expect(result.hasOwnProperty('pid')).toBeTruthy();
            expect(typeof result.pid).toBe('string');
        }, function (error) {
            fail('Should be able to add transaction to queue');
            done();
        }, function () {
            expect(1).toEqual(1);
            done();
        });
    });
    it('should be able to add a transaction and fail without socket being connected', function (done) {
        atajoXApi.addTransaction('fakeTransaction', {}, { queue: false }).subscribe(function (result) {
            fail('Can\'t transact directly without being connected to the socket');
            done();
        }, function (error) {
            expect(typeof error).toBe('string');
            done();
        }, function () {
            done();
        });
    });
    it('should be able to add a transaction and succeed with socket being connected', function (done) {
        atajoXConfig.set('domain', 'atajox');
        atajoXSocket.connect().then(function () {
            var atajoXApi = new AtajoXApi();
            atajoXApi.addTransaction('fakeTransaction', {}, { queue: false }).subscribe(function () {
                fail('A fakeTransaction should not succeed');
                done();
            }, function (error) {
                var transactions = AtajoXApi.getTransactions();
                var transactionCounter = 0;
                for (var key in transactions) {
                    if (transactions.hasOwnProperty(key)) {
                        transactionCounter++;
                    }
                }
                expect(transactionCounter).toEqual(1);
                done();
                atajoXSocket.disconnect();
            }, function () {
                done();
            });
        }, function (err) {
            console.log('FAIL HERE');
            console.log('err', err);
            done();
        });
    });
});
//# sourceMappingURL=api.spec.js.map