'use strict';
import { atajoXConsul } from "../consul/consul";
import { atajoXDevice } from "../device/device";
import { atajoXEvents } from "../events/events";
import { atajoXSocket } from "../socket/socket";
import { atajoXDatabase } from "../database/database";
var AtajoXConfig = /** @class */ (function () {
    function AtajoXConfig() {
        this.storeName = 'config';
        this.STATE = {
            api: {
                timeout: 30000
            },
            domain: '',
            lambdaGroup: '',
            environment: 'dev',
            consulAPIUrl: 'https://consul.atajo.io/v1/kv/',
            consulMapToken: '91dd05fe-3dc9-cd05-7938-3752d06b63d8',
            consulUpdateToken: '8494d9fb-943f-899e-45ef-cecb4646e9e1',
            consulClientToken: '',
            consulConfigManuallySet: false,
            consulConfig: {
                domain: '',
                key: '',
                url: '',
                owner: '',
                support: '',
                logo: '',
                icon: '',
                core: {
                    dev: { host: '', protocol: '', port: '', version: '' },
                    qas: { host: '', protocol: '', port: '', version: '' },
                    prd: { host: '', protocol: '', port: '', version: '' },
                }
            },
            update: {
                enabled: true,
                updateHash: '',
                updateURI: '',
                silent: false,
                key: {
                    android: {
                        dev: '9lTd-2cbm6mDIz2BuqfNCctHV-aYc114e27d-b55f-4180-a8ed-945ecbc98085',
                        qas: '9lTd-2cbm6mDIz2BuqfNCctHV-aYc114e27d-b55f-4180-a8ed-945ecbc98085',
                        prd: 'a6oJqbYO2wzndcqIpXDRdRCgWMB3c114e27d-b55f-4180-a8ed-945ecbc98085',
                    },
                    ios: {
                        dev: 'JcPd4jtUseaYwwuBlK-rbqMWVCJ_c114e27d-b55f-4180-a8ed-945ecbc98085',
                        qas: 'JcPd4jtUseaYwwuBlK-rbqMWVCJ_c114e27d-b55f-4180-a8ed-945ecbc98085',
                        prd: 'uZKNOMhDtCVR4VFgwLBt3pjf9mV6c114e27d-b55f-4180-a8ed-945ecbc98085',
                    }
                }
            },
            socket: {
                options: {
                    reconnection: true,
                    reconnectionAttempts: 50,
                    reconnectionDelay: 1000,
                    reconnectionDelayMax: 30000,
                    randomizationFactor: 0.5,
                    timeout: 10000,
                    autoConnect: true,
                    query: {
                        uuid: '',
                        key: '',
                        domain: '',
                        device: ''
                    }
                },
                notify: true,
            }
        };
    }
    AtajoXConfig.prototype.setCore = function (consulConfig) {
        if (this.STATE.domain === '') {
            console.error('Set domain first');
            return;
        }
        this.STATE.consulConfigManuallySet = true;
        this.STATE.consulConfig = consulConfig;
        this.saveState().then(function () {
            console.log('[setCore] Core set successfully');
        }, function () {
            console.error('[setCore] Could not save config state');
        });
    };
    /**
     * Set a new value in the existing STATE
     *
     * @param {string} key
     * @param value
     */
    AtajoXConfig.prototype.set = function (key, value) {
        this.STATE[key] = value;
        atajoXEvents.publish('config:change', key, value, Date.now());
        this.saveState().catch();
    };
    /**
     * Get a value from STATE
     *
     * @param {string} key
     * @param defaultValue
     * @returns {any}
     */
    AtajoXConfig.prototype.get = function (key, defaultValue) {
        if (defaultValue === void 0) { defaultValue = false; }
        try {
            var result = this.STATE[key];
            if (typeof result == 'undefined' || result == 'undefined') {
                return defaultValue;
            }
            if (result['dev'] && result['qas'] && result['prd']) {
                return result[this.STATE.environment];
            }
            return result;
        }
        catch (e) {
            return defaultValue;
        }
    };
    /**
     * Save config STATE from memory into storage
     *
     * @returns {Promise<void>}
     */
    AtajoXConfig.prototype.saveState = function () {
        return atajoXDatabase.setOrUpdate("key_value_pair", [{ column: "value", value: JSON.stringify(this.STATE) }], [{ column: "key", op: "=", value: this.storeName }]);
    };
    /**
     * Load config STATE from storage and store in memory
     *
     * @returns {Promise<void>}
     */
    AtajoXConfig.prototype.loadState = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            atajoXDatabase.get('key_value_pair', 'key = "' + _this.storeName + '"').then(function (pair) {
                if (pair.length > 0) {
                    _this.STATE = JSON.parse(pair[0].value);
                }
                resolve();
            }, function () {
                resolve();
            });
        });
    };
    /**
     * Initialise by loading state into memory
     * and updating it from Consul
     *
     * @returns {Promise<void>}
     */
    AtajoXConfig.prototype.initialise = function (config) {
        var _this = this;
        if (config === void 0) { config = {}; }
        return new Promise(function (resolve, reject) {
            _this.loadState().then(function () {
                for (var key in config) {
                    if (config.hasOwnProperty(key)) {
                        _this.STATE[key] = config[key];
                    }
                }
                if (_this.STATE.domain) {
                    _this.refresh(_this.STATE.domain).then(function () {
                        resolve();
                    }, function () {
                        reject('Unable to refresh');
                    });
                }
                else {
                    reject('Domain not configured');
                }
            }, function () {
                reject('Could not load state');
            });
        });
    };
    /**
     * Refresh state with remote config
     *
     * @param {string} domain
     * @param reset
     * @returns {Promise<any>}
     */
    AtajoXConfig.prototype.refresh = function (domain, reset) {
        var _this = this;
        if (domain === void 0) { domain = ''; }
        if (reset === void 0) { reset = false; }
        return new Promise(function (resolve, reject) {
            if (!domain) {
                reject('Domain not set, will not fetch remote config');
                return;
            }
            if (_this.STATE.consulConfigManuallySet) {
                _this.loadSocketQueryIntoState().then(function () {
                    resolve();
                }, function () {
                    reject('Could not load socket query into state');
                });
                return;
            }
            if (reset) {
                _this.STATE.consulClientToken = '';
            }
            atajoXConsul.getConfig(domain).then(function (config) {
                _this.STATE.domain = domain;
                _this.STATE.consulConfig = config;
                _this.loadSocketQueryIntoState().then(function () {
                    resolve();
                }, function () {
                    reject('Could not load socket query into state');
                });
            }, function (err) {
                if (!atajoXSocket.isConnected()) {
                    resolve();
                }
                else {
                    reject(err);
                }
            });
        });
    };
    /**
     * Load query required for socket connection
     *
     * @returns {Promise<ConfigStateSocketOptionsQuery>}
     */
    AtajoXConfig.prototype.loadSocketQueryIntoState = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            atajoXDevice.getInformation().then(function (deviceInformation) {
                var socketQuery = {
                    uuid: deviceInformation.uuid,
                    key: _this.STATE.consulConfig.key,
                    domain: _this.STATE.domain,
                    device: JSON.stringify(deviceInformation)
                };
                _this.STATE.socket.options.query = socketQuery;
                _this.saveState().then(function () {
                    resolve(socketQuery);
                }, function () {
                    reject('Could not save config state');
                });
            }, function () {
                reject();
            });
        });
    };
    return AtajoXConfig;
}());
export { AtajoXConfig };
export var atajoXConfig = new AtajoXConfig();
//# sourceMappingURL=config.js.map