'use strict';
import { atajoXConfig } from './config';
describe('AtajoXConfig', function () {
    it('should create a class', function () {
        expect(atajoXConfig).toBeDefined();
    });
    it('should have a state property', function () {
        expect(typeof atajoXConfig.STATE).toBe('object');
    });
    it('should conform to iConfigState model', function () {
        var state = atajoXConfig.STATE;
        expect(typeof state.domain).toBe('string');
        expect(typeof state.environment).toBe('string');
        expect(typeof state.consulAPIUrl).toBe('string');
        expect(typeof state.consulMapToken).toBe('string');
        expect(typeof state.consulUpdateToken).toBe('string');
        expect(typeof state.update).toBe('object');
        expect(typeof state.socket).toBe('object');
    });
    it('should be able to set a config value and assign it to STATE', function () {
        atajoXConfig.set('domain', 'test_domain');
        expect(atajoXConfig.STATE.domain).toEqual('test_domain');
    });
    it('should be able to get a config value by specifying a key', function () {
        expect(atajoXConfig.get('domain')).toEqual('test_domain'); // As set in previous test
    });
    // it('should save and retrieve STATE to and from localStorage', done => {
    //   interface iLocalStorageStore {
    //     [key: string]: any;
    //   }
    //   let store: iLocalStorageStore = {};
    //   spyOn(localStorage, 'getItem').and.callFake(function (key: string) {
    //     return store[key];
    //   });
    //   spyOn(localStorage, 'setItem').and.callFake(function (key: string, value: string) {
    //     return store[key] = value + '';
    //   });
    //   atajoXConfig.saveState().then(() => {
    //     expect(store[atajoXConfig.storeName]).toEqual(JSON.stringify(atajoXConfig.STATE));
    //     done();
    //   });
    //   atajoXConfig.loadState().then(() => {
    //     expect(atajoXConfig.STATE.domain).toEqual('test_domain'); // As set in previous test
    //     done();
    //   });
    // });
    it('should initialise and load config', function (done) {
        spyOn(atajoXConfig, 'loadState').and.callThrough();
        atajoXConfig.initialise().then(function () {
            expect(atajoXConfig.loadState).toHaveBeenCalledWith();
            done();
        }, function () {
            done();
        });
    });
    it('should load socket query information into state', function () {
        atajoXConfig.loadSocketQueryIntoState().then(function (socketQuery) {
            expect(socketQuery.domain).toEqual(atajoXConfig.STATE.socket.options.query.domain);
            expect(socketQuery.key).toEqual(atajoXConfig.STATE.socket.options.query.key);
            expect(socketQuery.uuid).toEqual(atajoXConfig.STATE.socket.options.query.uuid);
            expect(socketQuery.device).toEqual(atajoXConfig.STATE.socket.options.query.device);
        });
    });
});
//# sourceMappingURL=config.spec.js.map