'use strict';
var request = require('request');
import { AtajoXUtils } from '../utils/utils';
import { atajoXConfig } from '../config/config';
var AtajoXConsul = /** @class */ (function () {
    function AtajoXConsul() {
    }
    /**
     * Get config from Consul
     *
     * @param {string} domain
     * @returns {Promise<any>}
     */
    AtajoXConsul.prototype.getConfig = function (domain) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (atajoXConfig.STATE.consulClientToken) {
                resolve(atajoXConfig.STATE.consulConfig);
                return;
            }
            _this.getClientToken(domain).then(function (token) {
                _this.getClientConfig(domain, token).then(function (config) {
                    resolve(config);
                }, function (err) {
                    reject(err);
                });
            }, function (err) {
                reject(err);
            });
        });
    };
    /**
     * Get Client Token
     * for a specific domain
     *
     * @param {string} domain
     * @returns {Promise<string>}
     */
    AtajoXConsul.prototype.getClientToken = function (domain) {
        return new Promise(function (resolve, reject) {
            var key = 'mobility/domains/' + domain;
            request({
                url: atajoXConfig.STATE.consulAPIUrl + 'mobility/domains/map',
                method: 'GET',
                json: true,
                headers: {
                    'X-Consul-Token': atajoXConfig.STATE.consulMapToken
                }
            }, function (error, response, body) {
                if (error) {
                    reject('Could not retrieve domains from Consul');
                    return;
                }
                if (!body || !Array.isArray(body)) {
                    reject('Invalid response from Consul');
                    return;
                }
                if (!body[0].hasOwnProperty('Value')) {
                    reject('Consul response does not contain any value');
                    return;
                }
                var map = JSON.parse(AtajoXUtils.a2b(body[0].Value));
                if (!map.hasOwnProperty(key)) {
                    reject('Consul has no domain [' + key + ']');
                    return;
                }
                resolve(map[key]);
            });
        });
    };
    /**
     * Get Client Config
     * for a specific domain
     *
     * @param domain
     * @param token
     * @returns {Promise}
     */
    AtajoXConsul.prototype.getClientConfig = function (domain, token) {
        return new Promise(function (resolve, reject) {
            request({
                url: atajoXConfig.STATE.consulAPIUrl + 'mobility/domains/' + domain,
                method: 'GET',
                json: true,
                headers: {
                    'X-Consul-Token': token
                }
            }, function (error, response, body) {
                if (error) {
                    reject('Could not retrieve domain config from Consul');
                    return;
                }
                if (!body || !Array.isArray(body)) {
                    reject('Invalid response from Consul');
                    return;
                }
                if (!body[0].hasOwnProperty('Value')) {
                    reject('Consul response does not contain any value');
                    return;
                }
                var map = JSON.parse(AtajoXUtils.a2b(body[0].Value));
                resolve(map);
            });
        });
    };
    return AtajoXConsul;
}());
export { AtajoXConsul };
export var atajoXConsul = new AtajoXConsul();
//# sourceMappingURL=consul.js.map