'use strict';
import { atajoXDevice } from '../device/device';
import { atajoXWebSql } from './websql';
import { atajoXSQLite } from './sqlite';
import { atajoXDatabaseMigration } from "./migration";
var AtajoXDatabase = /** @class */ (function () {
    function AtajoXDatabase() {
    }
    /**
     * Initiates database
     *
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.init = function () {
        return new Promise(function (resolve, reject) {
            if (atajoXDevice.isCordova()) {
                atajoXSQLite.init().then(function () {
                    atajoXDatabaseMigration.run().then(function () {
                        resolve();
                    }, function () {
                        reject();
                    });
                });
            }
            else {
                atajoXWebSql.init().then(function () {
                    atajoXDatabaseMigration.run().then(function () {
                        resolve();
                    }, function () {
                        reject();
                    });
                });
            }
        });
    };
    /**
     * Deletes table completely
     *
     * @param {string} table
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.nuke = function (table) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.nuke(table);
        }
        else {
            return atajoXWebSql.nuke(table);
        }
    };
    /**
     * Get data from table
     *
     * @param {string} table
     * @param {string} where
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.get = function (table, where) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.get(table, where);
        }
        else {
            return atajoXWebSql.get(table, where);
        }
    };
    /**
     * Create new table
     *
     * @param {string} table
     * @param {Array<any>} columns
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.create = function (table, columns) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.create(table, columns);
        }
        else {
            return atajoXWebSql.create(table, columns);
        }
    };
    /**
     * Save data to table
     *
     * @param {string} table
     * @param values
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.set = function (table, values) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.set(table, values);
        }
        else {
            return atajoXWebSql.set(table, values);
        }
    };
    /**
     * Remove record(s) from table
     *
     * @param {string} table
     * @param {string} where
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.remove = function (table, where) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.remove(table, where);
        }
        else {
            return atajoXWebSql.remove(table, where);
        }
    };
    /**
     * Returns the row count
     *
     * @param {string} table
     * @param {string} where
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.count = function (table, where) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.count(table, where);
        }
        else {
            return atajoXWebSql.count(table, where);
        }
    };
    /**
     * Updates row(s) in table
     *
     * @param {string} table
     * @param values
     * @param where
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.update = function (table, values, where) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.update(table, values, where);
        }
        else {
            return atajoXWebSql.update(table, values, where);
        }
    };
    /**
     * Set or update row(s) in table
     *
     * @param table
     * @param values
     * @param where
     */
    AtajoXDatabase.prototype.setOrUpdate = function (table, values, where) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var getWhere = "";
            if (where) {
                var isFirstWhere_1 = true;
                where.forEach(function (w) {
                    if (!isFirstWhere_1) {
                        getWhere += " AND ";
                    }
                    getWhere += w.column + " " + w.op + " '" + w.value + "'";
                });
            }
            _this.get(table, getWhere).then(function (row) {
                if (row.length === 0) {
                    var objToSet_1 = {};
                    if (values) {
                        values.forEach(function (valueData) {
                            objToSet_1[valueData.column] = valueData.value;
                        });
                    }
                    if (where) {
                        where.forEach(function (whereData) {
                            objToSet_1[whereData.column] = whereData.value;
                        });
                    }
                    _this.set(table, [objToSet_1]).then(function () {
                        resolve();
                    }, function () {
                        reject();
                    });
                }
                else {
                    _this.update(table, values, where).then(function () {
                        resolve();
                    }, function () {
                        reject();
                    });
                }
            }, function () {
                reject();
            });
        });
    };
    /**
     * Adds a column to database
     *
     * @param {string} table
     * @param {any} column
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.addColumn = function (table, column) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.addColumn(table, column);
        }
        else {
            return atajoXWebSql.addColumn(table, column);
        }
    };
    /**
     * Adds a index to database
     *
     * @param {string} table
     * @param {any} column
     * @returns {Promise<any>}
     */
    AtajoXDatabase.prototype.addIndex = function (table, column) {
        if (atajoXDevice.isCordova()) {
            return atajoXSQLite.addIndex(table, column);
        }
        else {
            return new Promise(function (resolve, reject) {
                resolve();
            });
        }
    };
    return AtajoXDatabase;
}());
export { AtajoXDatabase };
export var atajoXDatabase = new AtajoXDatabase();
//# sourceMappingURL=database.js.map