'use strict';
import { atajoXSQLite } from './sqlite';
describe('AtajoXSQLite', function () {
    var fakeDatabaseData = null;
    window.sqlitePlugin =
        {
            openDatabase: function (obj) {
                return {
                    transaction: function () {
                    }
                };
            }
        };
    beforeEach(function () {
        if (typeof atajoXSQLite.getDb() != 'undefined') {
            spyOn(atajoXSQLite.getDb(), 'transaction').and.callFake(function (cb) {
                cb({ executeSql: executeSql });
            });
        }
    });
    var executeSql = function (query, dataset, success, fail) {
        if (query.indexOf('DROP TABLE') >= 0) {
            fakeDatabaseData = null;
            success();
        }
        else if (query.indexOf('SELECT * FROM') >= 0) {
            if (fakeDatabaseData == null) {
                fail(null, 'Table doesnt exist');
            }
            else {
                var resultRows_1 = [];
                if (query.indexOf('WHERE') >= 0) {
                    var split = query.split('WHERE');
                    split = split[1].split('=');
                    for (var i in fakeDatabaseData) {
                        if (fakeDatabaseData.hasOwnProperty(i)) {
                            if (parseInt(fakeDatabaseData[i][split[0].trim()]) === parseInt(split[1])) {
                                resultRows_1.push(fakeDatabaseData[i]);
                            }
                        }
                    }
                }
                else {
                    resultRows_1 = fakeDatabaseData;
                }
                var resultSet = {
                    rows: {
                        length: resultRows_1.length,
                        item: function (i) {
                            return resultRows_1[i];
                        }
                    }
                };
                success(null, resultSet);
            }
        }
        else if (query.indexOf('SELECT COUNT(*)') >= 0) {
            var resultRows_2 = [{
                    'COUNT(*)': fakeDatabaseData.length
                }];
            var resultSet = {
                rows: {
                    length: resultRows_2.length,
                    item: function (i) {
                        return resultRows_2[i];
                    }
                }
            };
            success(null, resultSet);
        }
        else if (query.indexOf('CREATE TABLE') >= 0) {
            fakeDatabaseData = [];
            success();
        }
        else if (query.indexOf('INSERT INTO') >= 0) {
            var count = 0; //arg1.length;
            var split = query.split('(');
            split = split[1].split(')');
            split = split[0].split(',');
            while (count < dataset.length) {
                var row = {};
                for (var i in split) {
                    row[split[i].trim()] = dataset[count];
                    count++;
                }
                fakeDatabaseData.push(row);
            }
            success();
        }
        else if (query.indexOf('DELETE FROM ') >= 0) {
            var split = query.split('WHERE');
            split = split[1].split('=');
            for (var i in fakeDatabaseData) {
                if (parseInt(fakeDatabaseData[i][split[0].trim()]) === parseInt(split[1])) {
                    fakeDatabaseData.splice(i, 1);
                    break;
                }
            }
            success();
        }
        else if (query.indexOf('UPDATE') >= 0) {
            var split = query.split('SET ');
            var toChange = split[1].split('=?')[0];
            split = query.split('WHERE ');
            var where = split[1].split('=?')[0];
            for (var i in fakeDatabaseData) {
                if (parseInt(fakeDatabaseData[i][where.trim()]) === parseInt(dataset[1])) {
                    fakeDatabaseData[i][toChange.trim()] = dataset[0];
                }
            }
            success();
        }
        else {
            success('Unknown Test');
        }
    };
    it('should create a class', function () {
        expect(atajoXSQLite).toBeDefined();
    });
    it('should be able to init webSql and db should be defined', function (done) {
        atajoXSQLite.init().then(function () {
            expect(atajoXSQLite.getDb()).toBeDefined();
            done();
        }, function () {
            done();
        });
    });
    it('should be able to nuke a table', function (done) {
        atajoXSQLite.nuke('test_table').then(function () {
            atajoXSQLite.get('test_table').then(function (response) {
                fail('Table should not exist.');
                done();
            }).catch(function (err) {
                expect(err).toBeDefined();
                done();
            });
        });
    });
    it('should be able to create and read a table', function (done) {
        atajoXSQLite.create('test_table', [{ name: 'test_column_int', type: 'INT' }, {
                name: 'test_column_string',
                type: 'VARCHAR(10)'
            }]).then(function () {
            atajoXSQLite.get('test_table').then(function (response) {
                expect(response).toEqual([]);
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to write and read a row', function (done) {
        atajoXSQLite.set('test_table', [{ test_column_int: '1', test_column_string: '1' }]).then(function () {
            atajoXSQLite.get('test_table').then(function (response) {
                expect(response.length).toEqual(1);
                expect(response[0]).toBeDefined();
                expect(response[0].test_column_int).toEqual('1');
                expect(response[0].test_column_string).toEqual('1');
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to remove a row', function (done) {
        atajoXSQLite.remove('test_table', "test_column_int = 1").then(function () {
            atajoXSQLite.get('test_table').then(function (response) {
                expect(response).toEqual([]);
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to write and read multiple rows', function (done) {
        atajoXSQLite.set('test_table', [{ test_column_int: '2', test_column_string: '2' }, {
                test_column_int: '3',
                test_column_string: '3'
            }]).then(function () {
            //Get all rows.
            atajoXSQLite.get('test_table').then(function (response) {
                expect(response.length).toEqual(2);
                expect(response[0]).toBeDefined();
                expect(response[1]).toBeDefined();
                expect(response[0].test_column_int).toEqual('2');
                expect(response[0].test_column_string).toEqual('2');
                expect(response[1].test_column_int).toEqual('3');
                expect(response[1].test_column_string).toEqual('3');
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to read a single row', function (done) {
        //Get single rows.
        atajoXSQLite.get('test_table', 'test_column_int = 3').then(function (response) {
            expect(response.length).toEqual(1);
            expect(response[0]).toBeDefined();
            expect(response[0].test_column_int).toEqual('3');
            expect(response[0].test_column_string).toEqual('3');
            done();
        }).catch(function (err) {
            fail('Could not read from created table.' + err);
            done();
        });
    });
    it('should be able to count rows', function (done) {
        atajoXSQLite.count('test_table').then(function (response) {
            //theres should only be 2 rows in the table.
            expect(response).toEqual(2);
            done();
        }).catch(function (err) {
            fail('Could not count from.' + err);
            done();
        });
    });
    it('should be able to update a row', function (done) {
        atajoXSQLite.update('test_table', [{ column: 'test_column_string', value: '4' }], [{
                column: 'test_column_int',
                op: '=',
                value: 3
            }]).then(function () {
            //GetAll to make sure only 1 row updated.
            atajoXSQLite.get('test_table').then(function (response) {
                expect(response.length).toEqual(2);
                expect(response[0]).toBeDefined();
                expect(response[1]).toBeDefined();
                expect(response[0].test_column_int).toEqual('2');
                expect(response[0].test_column_string).toEqual('2');
                expect(response[1].test_column_int).toEqual('3');
                expect(response[1].test_column_string).toEqual('4');
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        }).catch(function (err) {
            fail('Could not count from.' + err);
            done();
        });
    });
});
//# sourceMappingURL=sqlite.spec.js.map