'use strict';
import { atajoXWebSql } from './websql';
describe('websql', function () {
    it('should create a class', function () {
        expect(atajoXWebSql).toBeDefined();
    });
    it('should be able to init websql and db should be defined', function (done) {
        atajoXWebSql.init().then(function () {
            expect(atajoXWebSql.db).toBeDefined();
            done();
        });
    });
    it('should be able to nuke a table', function (done) {
        atajoXWebSql.nuke('test_table').then(function () {
            atajoXWebSql.get('test_table').then(function (response) {
                fail('Table should not exist.');
                done();
            }).catch(function (err) {
                expect(err).toBeDefined();
                done();
            });
        });
    });
    it('should be able to create and read a table', function (done) {
        atajoXWebSql.create('test_table', [{ name: 'test_column_int', type: 'INT' }, {
                name: 'test_column_string',
                type: 'VARCHAR(10)'
            }]).then(function () {
            atajoXWebSql.get('test_table').then(function (response) {
                expect(response).toEqual([]);
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to write and read a row', function (done) {
        atajoXWebSql.set('test_table', [{ test_column_int: '1', test_column_string: '1' }]).then(function () {
            atajoXWebSql.get('test_table').then(function (response) {
                expect(response.length).toEqual(1);
                expect(response[0]).toBeDefined();
                expect(response[0].test_column_int).toEqual(1);
                expect(response[0].test_column_string).toEqual('1');
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to remove a row', function (done) {
        atajoXWebSql.remove('test_table', "test_column_int = 1").then(function () {
            atajoXWebSql.get('test_table').then(function (response) {
                expect(response).toEqual([]);
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to write and read multiple rows', function (done) {
        atajoXWebSql.set('test_table', [{ test_column_int: '2', test_column_string: '2' }, {
                test_column_int: '3',
                test_column_string: '3'
            }]).then(function () {
            //Get all rows.
            atajoXWebSql.get('test_table').then(function (response) {
                expect(response.length).toEqual(2);
                expect(response[0]).toBeDefined();
                expect(response[1]).toBeDefined();
                expect(response[0].test_column_int).toEqual(2);
                expect(response[0].test_column_string).toEqual('2');
                expect(response[1].test_column_int).toEqual(3);
                expect(response[1].test_column_string).toEqual('3');
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        });
    });
    it('should be able to read a single row', function (done) {
        //Get single rows.
        atajoXWebSql.get('test_table', 'test_column_int = 3').then(function (response) {
            expect(response.length).toEqual(1);
            expect(response[0]).toBeDefined();
            expect(response[0].test_column_int).toEqual(3);
            expect(response[0].test_column_string).toEqual('3');
            done();
        }).catch(function (err) {
            fail('Could not read from created table.' + err);
            done();
        });
    });
    it('should be able to count rows', function (done) {
        atajoXWebSql.count('test_table').then(function (response) {
            //theres should only be 2 rows in the table.
            expect(response).toEqual(2);
            done();
        }).catch(function (err) {
            fail('Could not count from.' + err);
            done();
        });
    });
    it('should be able to update a row', function (done) {
        atajoXWebSql.update('test_table', [{ column: 'test_column_string', value: '4' }], [{
                column: 'test_column_int',
                op: '=',
                value: 3
            }]).then(function () {
            //GetAll to make sure only 1 row updated.
            atajoXWebSql.get('test_table').then(function (response) {
                expect(response.length).toEqual(2);
                expect(response[0]).toBeDefined();
                expect(response[1]).toBeDefined();
                expect(response[0].test_column_int).toEqual(2);
                expect(response[0].test_column_string).toEqual('2');
                expect(response[1].test_column_int).toEqual(3);
                expect(response[1].test_column_string).toEqual('4');
                done();
            }).catch(function (err) {
                fail('Could not read from created table.' + err);
                done();
            });
        }).catch(function (err) {
            fail('Could not count from.' + err);
            done();
        });
    });
});
//# sourceMappingURL=websql.spec.js.map