import { DeviceBattery, DeviceModel } from "./device.model";
export declare class AtajoXDevice {
    battery: DeviceBattery;
    constructor();
    /**
     * Get device information
     *
     * @returns {Promise<DeviceModel>}
     */
    getInformation(): Promise<DeviceModel>;
    /**
     * Get network information
     * @returns {Promise<string>}
     */
    getNetworkInformation(): Promise<string>;
    /**
     * Retrieve signal strength
     * @returns {Promise<string>}
     */
    getSignalStrength(): Promise<string>;
    /**
     * Returns the app name
     * @returns {Promise<string>}
     */
    getAppName(): Promise<string>;
    /**
     * Returns the package name
     * @returns {Promise<string>}
     */
    getPackageName(): Promise<string>;
    /**
     * Returns the version code
     * @returns {Promise<string>}
     */
    getVersionCode(): Promise<string>;
    /**
     * Returns the version number
     * @returns {Promise<string>}
     */
    getVersionNumber(): Promise<string>;
    /**
     * Returns the device uuid
     *
     * @returns {Promise<string>}
     */
    getUuid(): Promise<string>;
    /**
     * Returns the platform type
     *
     * @returns {string}
     */
    getPlatform(): string;
    /**
     * Returns the device version
     *
     * @returns {number}
     */
    getDeviceVersion(): number;
    /**
     * Returns the device manufacturer
     *
     * @returns {string}
     */
    getManufacturer(): string;
    /**
     * Returns the device model
     *
     * @returns {string}
     */
    getModel(): string;
    /**
     * Returns the Cordova version
     *
     * @returns {string}
     */
    getCordovaVersion(): string;
    /**
     * Returns the device serial
     *
     * @returns {string}
     */
    getSerial(): string;
    /**
     * Checks if Cordova is available
     * This is only true when running on device
     *
     * @returns {boolean}
     */
    isCordova(): boolean;
    /**
     * Subscribe to battery events
     */
    addBatteryEventListeners(): void;
    /**
     * Set battery state
     *
     * @param {any} status
     * @private
     */
    onBatteryChange(status: any): void;
}
export declare let atajoXDevice: AtajoXDevice;
