'use strict';
import { atajoXDevice } from './device';
describe('Device', function () {
    it('should create a class', function () {
        expect(atajoXDevice).toBeDefined();
    });
    it('should return device information', function (done) {
        spyOn(atajoXDevice, 'getAppName').and.callThrough();
        spyOn(atajoXDevice, 'getPackageName').and.callThrough();
        spyOn(atajoXDevice, 'getVersionCode').and.callThrough();
        spyOn(atajoXDevice, 'getVersionNumber').and.callThrough();
        atajoXDevice.getInformation().then(function (deviceInformation) {
            expect(atajoXDevice.getAppName).toHaveBeenCalled();
            expect(atajoXDevice.getPackageName).toHaveBeenCalled();
            expect(atajoXDevice.getVersionCode).toHaveBeenCalled();
            expect(atajoXDevice.getVersionNumber).toHaveBeenCalled();
            expect(typeof deviceInformation.platform).toBe('string');
            done();
        });
    });
    it('should return an app name', function (done) {
        atajoXDevice.getAppName().then(function (appName) {
            expect(typeof appName).toBe('string');
            done();
        });
    });
    it('should return a package name', function (done) {
        atajoXDevice.getPackageName().then(function (packageName) {
            expect(typeof packageName).toBe('string');
            done();
        });
    });
    it('should return a version code', function (done) {
        atajoXDevice.getVersionCode().then(function (versionCode) {
            expect(typeof versionCode).toBe('string');
            done();
        });
    });
    it('should return a version number', function (done) {
        atajoXDevice.getVersionNumber().then(function (versionCode) {
            expect(typeof versionCode).toBe('string');
            done();
        });
    });
    it('should return a uuid', function () {
        expect(typeof atajoXDevice.getUuid()).toEqual('string');
    });
    it('should return a platform', function () {
        expect(atajoXDevice.getPlatform()).toEqual('web');
    });
    it('should return a device version', function () {
        expect(typeof atajoXDevice.getDeviceVersion()).toEqual('number');
    });
    it('should return a manufacturer', function () {
        expect(typeof atajoXDevice.getManufacturer()).toEqual('string');
    });
    it('should return a model', function () {
        expect(typeof atajoXDevice.getModel()).toEqual('string');
    });
    it('should return a Cordova version', function () {
        expect(typeof atajoXDevice.getCordovaVersion()).toEqual('string');
    });
    it('should return a serial number', function () {
        expect(typeof atajoXDevice.getSerial()).toEqual('string');
    });
    it('should return false when checking if Cordova in test', function () {
        expect(atajoXDevice.isCordova()).toBeFalsy();
    });
    it('should set a default battery state', function () {
        expect(atajoXDevice.battery.level).toEqual('unknown');
        expect(atajoXDevice.battery.isCharging).toEqual(false);
    });
    it('should update battery property', function () {
        expect(atajoXDevice.battery.level).toEqual('unknown');
        atajoXDevice.onBatteryChange({ level: 50, isPlugged: true });
        expect(atajoXDevice.battery.level).toEqual('50');
        expect(atajoXDevice.battery.isCharging).toEqual(true);
    });
});
//# sourceMappingURL=device.spec.js.map