'use strict';
var AtajoXEvents = /** @class */ (function () {
    function AtajoXEvents() {
        this.channels = [];
    }
    /**
     * Subscribe to an event topic. Events that get posted to that topic will trigger the provided handler.
     *
     * @param {string} topic the topic to subscribe to
     * @param {Function} handlers the event handler
     */
    AtajoXEvents.prototype.subscribe = function (topic) {
        var _this = this;
        var handlers = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            handlers[_i - 1] = arguments[_i];
        }
        if (!this.channels[topic]) {
            this.channels[topic] = [];
        }
        handlers.forEach(function (handler) {
            _this.channels[topic].push(handler);
        });
    };
    /**
     * Unsubscribe from the given topic. Your handler will no longer receive events published to this topic.
     *
     * @param {string} topic the topic to unsubscribe from
     * @param {Function} handler the event handler
     * @returns {boolean} true if a handler was removed
     */
    AtajoXEvents.prototype.unsubscribe = function (topic, handler) {
        if (handler === void 0) { handler = function () { }; }
        if (this.channels.hasOwnProperty(topic)) {
            delete this.channels[topic];
            return true;
        }
        return false;
    };
    /**
     * Publish an event to the given topic.
     *
     * @param {string} topic the topic to publish to
     * @param args eventData the data to send as the event
     * @returns {any}
     */
    AtajoXEvents.prototype.publish = function (topic) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var t = this.channels[topic];
        if (!t) {
            return null;
        }
        var responses = [];
        t.forEach(function (handler) {
            responses.push(handler.apply(void 0, args));
        });
        return responses;
    };
    return AtajoXEvents;
}());
export { AtajoXEvents };
export var atajoXEvents = new AtajoXEvents();
//# sourceMappingURL=events.js.map