import { iOptions } from './graph.model';
export declare class AtajoXGraph {
    libName: string;
    availableChartTypes: Array<string>;
    ringTruePercentage: any;
    steps: number;
    _c: HTMLCanvasElement;
    _ctx: CanvasRenderingContext2D;
    _ratio: number;
    _xAxisLength: number;
    _yAxisLength: number;
    _xAxisStartX: number;
    _xAxisStartY: number;
    _xAxisEndX: number;
    _xAxisEndY: number;
    _yAxisStartX: number;
    _yAxisStartY: number;
    _yAxisEndX: number;
    _yAxisEndY: number;
    _gutter: number;
    _nudge: number;
    _serieSpacing: number;
    _options: iOptions;
    constructor(options: any);
    /**
     * Get graph options
     *
     * @returns {iOptions}
     */
    getOptions(): iOptions;
    /**
     * Show error in console
     *
     * @param {string} msg
     */
    error(msg: string): void;
    /**
     * Set graph options
     *
     * @param options
     * @private
     */
    private _setOptions(options);
    /**
     * Run setup to initiate graph
     *
     * @private
     */
    private _setup();
    /**
     * Set default graph options
     *
     * @private
     */
    private _setDefaultOptions();
    /**
     * Check if there are any issues with graph options
     *
     * @param options
     * @private
     */
    private _checkOptionErrors(options);
    /**
     * Set up axis
     *
     * @private
     */
    _axisSetup(): void;
    /**
     * Draw graph title
     *
     * @private
     */
    _drawTitle(): void;
    /**
     * Draw graph grid
     *
     * @param options
     * @private
     */
    private _drawGrid(options?);
    /**
     * Draw X Series
     * @private
     */
    private _drawXSeries();
    /**
     * Draw X Serie marker
     *
     * @param xPoint
     * @param label
     * @private
     */
    private _drawXSerieMarker(xPoint, label);
    /**
     * Get line curve points
     *
     * @param ptsa
     * @returns {Array<number>}
     * @private
     */
    private _getLineCurvePoints(ptsa);
    /**
     * Draw graph lines
     *
     * @param ctx
     * @param pts
     * @private
     */
    private _drawLines(ctx, pts);
    /**
     * Draw area fill
     *
     * @param ctx
     * @param pts
     * @private
     */
    private _drawAreaFill(ctx, pts);
    /**
     * Draw line chart
     *
     * @private
     */
    _drawLineChart(): void;
    /**
     * Draw ring chart
     *
     * @private
     */
    _drawRingChart(): void;
    /**
     * Convert percentage to radians
     *
     * @param percentage
     * @returns {iPercentageToRadians}
     * @private
     */
    private _percentageToRadians(percentage);
    /**
     * Draw bar chart
     *
     * @private
     */
    _drawBarChart(): void;
    /**
     * Draw bars
     *
     * @private
     */
    private _drawBars();
    /**
     * Draw horizontal bar chart
     *
     * @private
     */
    _drawBarHorizontalChart(): void;
    /**
     * Animate graph
     *
     * @private
     */
    _animate(): void;
}
