'use strict';
import { AtajoXGraph } from './graph';
describe('AtajoXGraph', function () {
    var graph;
    beforeEach(function () {
        spyOn(document, 'getElementById').and.callFake(function (id) {
            return {
                height: 150,
                width: 300,
                parentElement: {
                    offsetWidth: 300
                },
                style: {},
                getContext: function (id) {
                    return {
                        fillText: function () {
                        },
                        beginPath: function () {
                        },
                        moveTo: function () {
                        },
                        lineTo: function () {
                        },
                        stroke: function () {
                        },
                        arc: function () {
                        },
                        fill: function () {
                        },
                        clearRect: function () {
                        },
                        closePath: function () {
                        },
                        fillRect: function () {
                        }
                    };
                }
            };
        });
        spyOn(window, 'requestAnimationFrame').and.callFake(function (id) {
            return {};
        });
        spyOn(window, 'cancelAnimationFrame').and.callFake(function (id) {
            return {};
        });
    });
    it('should create a class', function () {
        var options = {};
        graph = new AtajoXGraph(options);
        expect(graph).toBeDefined();
    });
    it('should set default graph options', function () {
        var options = {};
        graph = new AtajoXGraph(options);
        expect(graph.getOptions()).toBeDefined();
    });
    it('should print an error', function () {
        spyOn(console, 'error').and.callFake(function (message) {
            expect(message).toContain('test error');
        });
        graph.error('test error');
    });
    it('should be able to get color error', function () {
        spyOn(console, 'error').and.callFake(function (message) {
            expect(message).toContain('Only use two colours');
        });
        var newOptions = {
            colors: ['#055d8d', '#1279be', '#1279be'],
        };
        graph = new AtajoXGraph(newOptions);
    });
    it('should be able to get available type error', function () {
        spyOn(console, 'error').and.callFake(function (message) {
            expect(message).toContain(' types of charts are available: ');
        });
        var newOptions = {
            type: 'parrot',
        };
        graph = new AtajoXGraph(newOptions);
    });
    it('should be able to get data/series error', function () {
        spyOn(console, 'error').and.callFake(function (message) {
            expect(message).toContain('You need to have a');
        });
        var newOptions = {
            type: 'line',
            series: false
        };
        graph = new AtajoXGraph(newOptions);
    });
    it('should be able to get ring without percentage error', function () {
        spyOn(console, 'error').and.callFake(function (message) {
            expect(message).toContain('You need to have a percentage integer in your options');
        });
        var newOptions = {
            type: 'ring'
        };
        graph = new AtajoXGraph(newOptions);
    });
    it('should be able to set options', function () {
        var newOptions = {
            type: 'ring'
        };
        graph = new AtajoXGraph(newOptions);
        expect(graph.getOptions().type).toEqual('ring');
    });
    it('should call all line chart functions', function () {
        spyOn(AtajoXGraph.prototype, "_axisSetup").and.callThrough();
        spyOn(AtajoXGraph.prototype, '_drawLineChart').and.callThrough();
        spyOn(AtajoXGraph.prototype, '_animate').and.callThrough();
        spyOn(AtajoXGraph.prototype, '_drawTitle').and.callThrough();
        var newOptions = {
            type: 'line',
            series: ['x', 'y'],
            data: [1, 2, 3, 4, 5],
            title: 'fake Title'
        };
        graph = new AtajoXGraph(newOptions);
        expect(AtajoXGraph.prototype._axisSetup).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._drawLineChart).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._animate).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._drawTitle).toHaveBeenCalled();
    });
    it('should call all ring chart functions', function () {
        spyOn(AtajoXGraph.prototype, "_drawRingChart").and.callThrough();
        spyOn(AtajoXGraph.prototype, '_animate').and.callThrough();
        var newOptions = {
            type: 'ring',
            series: ['x', 'y'],
            data: [1, 2, 3, 4, 5],
            title: 'fake Title',
            percentage: 10
        };
        graph = new AtajoXGraph(newOptions);
        expect(AtajoXGraph.prototype._drawRingChart).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._animate).toHaveBeenCalled();
    });
    it('should call all bar chart functions', function () {
        spyOn(AtajoXGraph.prototype, "_axisSetup").and.callThrough();
        spyOn(AtajoXGraph.prototype, "_drawBarChart").and.callThrough();
        spyOn(AtajoXGraph.prototype, '_animate').and.callThrough();
        var newOptions = {
            type: 'bar',
            series: ['x', 'y'],
            data: [1, 2, 3, 4, 5],
            title: 'fake Title'
        };
        graph = new AtajoXGraph(newOptions);
        expect(AtajoXGraph.prototype._axisSetup).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._drawBarChart).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._animate).toHaveBeenCalled();
    });
    it('should call all bar_horizontal chart functions', function () {
        spyOn(AtajoXGraph.prototype, "_drawBarHorizontalChart").and.callThrough();
        spyOn(AtajoXGraph.prototype, '_animate').and.callThrough();
        var newOptions = {
            type: 'bar_horizontal',
            series: ['x', 'y'],
            data: [1, 2, 3, 4, 5],
            title: 'fake Title'
        };
        graph = new AtajoXGraph(newOptions);
        expect(AtajoXGraph.prototype._drawBarHorizontalChart).toHaveBeenCalled();
        expect(AtajoXGraph.prototype._animate).toHaveBeenCalled();
    });
});
//# sourceMappingURL=graph.spec.js.map