'use strict';
import { atajoXEvents } from "../events/events";
import { atajoXSocket } from "../socket/socket";
import { atajoXDatabase } from "../database/database";
var AtajoXQueue = /** @class */ (function () {
    function AtajoXQueue() {
        var _this = this;
        this.columns = [];
        this.tableName = 'atajoApiQueue';
        this.processInterval = false;
        this.columns =
            [
                {
                    name: 'pid',
                    type: 'VARCHAR(64) PRIMARY KEY NOT NULL'
                }, {
                    name: 'tx',
                    type: 'TEXT'
                }, {
                    name: 'status',
                    type: 'VARCHAR(10)'
                }, {
                    name: 'submitAt',
                    type: 'INT'
                }, {
                    name: 'responseAt',
                    type: 'INT'
                }
            ];
        atajoXEvents.subscribe('socket:connect', function () {
            atajoXDatabase.create(_this.tableName, _this.columns).then(function () {
                _this.queueBusy(); // FAIL ALL BUSY JOBS
                _this.startProcess();
            }, function () {
                console.error("TABLE " + _this.tableName + " NOT CREATED");
            });
        });
        atajoXEvents.subscribe('socket:status', function (data) {
            if (data.nodes == 0) {
                //Fail all busy jobs.
                _this.list('BUSY').then(function (queue) {
                    var _loop_1 = function (i) {
                        var job = queue[i];
                        atajoXDatabase.update(_this.tableName, [{ column: "status", value: "FAILED" }], [{ column: "pid", op: "=", value: job.pid }]).then(function () {
                            atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: job.pid, data: false });
                        }, function () {
                            atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: job.pid, data: false });
                        });
                    };
                    for (var i in queue) {
                        _loop_1(i);
                    }
                }, function () {
                    atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: 0, data: false });
                });
            }
            else {
                _this.startProcess();
            }
        });
        atajoXEvents.subscribe('socket:disconnect', function () {
            _this.stopProcess();
            _this.failAllJobs();
        });
        atajoXEvents.subscribe('socket:client:rx', function (tx) {
            _this.transactionResponse(tx);
        });
    }
    /**
     * Fail all jobs
     */
    AtajoXQueue.prototype.failAllJobs = function () {
        var _this = this;
        this.list('BUSY').then(function (queue) {
            var _loop_2 = function (i) {
                var job = queue[i];
                atajoXDatabase.update(_this.tableName, [{ column: "status", value: "FAILED" }], [{ column: "pid", op: "=", value: job.pid }]).then(function () {
                    atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: job.pid, data: false });
                }, function () {
                    atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: job.pid, data: false });
                });
            };
            for (var i in queue) {
                _loop_2(i);
            }
        }, function () {
            atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: 0, data: false });
        });
    };
    /**
     * Start queue processing
     */
    AtajoXQueue.prototype.startProcess = function () {
        var _this = this;
        if (!this.processInterval) {
            setTimeout(function () { _this.process(); }, 1000);
            this.processInterval = setInterval(function () {
                _this.process();
            }, 10000);
        }
    };
    /**
     * Stop queue processing
     */
    AtajoXQueue.prototype.stopProcess = function () {
        clearInterval(this.processInterval);
        this.processInterval = false;
    };
    /**
     * Process queue
     */
    AtajoXQueue.prototype.process = function () {
        var _this = this;
        if (atajoXSocket.isConnected()) {
            this.list().then(function (queue) {
                var hadQueued = false;
                var _loop_3 = function (i) {
                    if (queue.hasOwnProperty(i)) {
                        var job_1 = queue[i];
                        if (job_1.status == 'QUEUED') {
                            hadQueued = true;
                            atajoXDatabase.update(_this.tableName, [{ column: "status", value: "BUSY" }], [{ column: "pid", op: "=", value: job_1.pid }]).then(function () {
                                atajoXEvents.publish('queue:update', { pid: job_1.pid, status: 'BUSY' });
                                var transaction = job_1.tx;
                                if (typeof transaction === 'string') {
                                    transaction = JSON.parse(transaction);
                                }
                                transaction.latency = transaction.latency || {};
                                transaction.latency.deviceRequestAt = new Date().getTime();
                                atajoXSocket.transaction(transaction);
                            }, function () {
                            }).catch(function (error) { return console.log("COULD NOT UPDATE JOB : ", error); });
                        }
                    }
                };
                for (var i in queue) {
                    _loop_3(i);
                }
                if (!hadQueued) {
                    _this.stopProcess();
                }
            }, function () {
            }).catch(function (error) { });
        }
        else {
            console.debug("QUEUE: NOT CONNECTED");
            this.stopProcess();
        }
    };
    /**
     * Transaction Response
     *
     * Process transaction when it comes back from lambdas
     *
     * @param rx
     */
    AtajoXQueue.prototype.transactionResponse = function (rx) {
        var _this = this;
        if (rx.pid) {
            var pid_1 = rx.pid;
            atajoXDatabase.get(this.tableName, "pid='" + pid_1 + "'").then(function (transaction) {
                if (transaction) {
                    if (typeof (rx.response) == 'undefined') {
                        atajoXDatabase.update(_this.tableName, [{ column: "status", value: "DONE" }], [{ column: "pid", op: "=", value: pid_1 }]).then(function () {
                            atajoXEvents.publish('queue:update', { error: 0, progress: 100, pid: pid_1, data: null });
                        }, function () {
                            atajoXEvents.publish('queue:update', { error: 1, progress: 100, pid: pid_1, data: null });
                        });
                        return;
                    }
                    if (rx.hasOwnProperty('response') === false) {
                        atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: pid_1, data: rx });
                        return;
                    }
                    //CALC PERCENTAGES FROM CHUNKS
                    var chunkId = rx.response.chunkId + 1;
                    var chunkTotal = rx.response.chunkTotal;
                    var progress_1 = (100 / chunkTotal) * chunkId;
                    progress_1 = isNaN(progress_1) ? 0 : progress_1;
                    if (!rx.response.data)
                        rx.response.data = [];
                    if (Array.isArray(rx.response.data)) {
                        if (rx.response.data.length == 1) {
                            rx.response.data = rx.response.data[0];
                        }
                    }
                    if (rx.error) {
                        atajoXDatabase.update(_this.tableName, [{ column: "status", value: "FAILED" }], [{ column: "pid", op: "=", value: pid_1 }]).then(function () {
                            atajoXEvents.publish('queue:update', { error: 1, progress: progress_1, pid: pid_1, data: rx.response.data });
                        }, function () {
                            atajoXEvents.publish('queue:update', { error: 1, progress: progress_1, pid: pid_1, data: rx.response.data });
                        });
                    }
                    else {
                        atajoXDatabase.update(_this.tableName, [{ column: "status", value: "DONE" }], [{ column: "pid", op: "=", value: pid_1 }]).then(function () {
                            atajoXEvents.publish('queue:update', { error: 0, progress: progress_1, pid: pid_1, data: rx.response.data });
                        }, function () {
                            atajoXEvents.publish('queue:update', { error: 1, progress: progress_1, pid: pid_1, data: rx.response.data });
                        });
                    }
                }
                else {
                    console.warn("REALTIME TRANSACTION FOR " + pid_1 + " NOT CACHED - POSSIBLY QUEUED");
                }
            }, function () {
                atajoXEvents.publish('queue:update', { error: 1, progress: 0, pid: pid_1, data: rx.response.data });
            });
        }
        else {
            console.error("SOCKET:TX_RESPONSE INVALID : ", rx);
        }
    };
    /**
     * Add transaction to the queue and process
     *
     * @param {String} pid
     * @param {ApiTransaction} transaction
     */
    AtajoXQueue.prototype.add = function (pid, transaction) {
        transaction.latency.deviceQueuedAt = new Date().getTime();
        var queuedTx = {
            latency: transaction.latency,
            payload: transaction.payload,
            at: transaction.at,
            status: transaction.status,
            lambda: transaction.lambda,
            queue: transaction.queue,
            version: transaction.version,
            environment: transaction.environment
        };
        atajoXDatabase.set(this.tableName, [
            {
                pid: pid,
                tx: queuedTx,
                status: 'QUEUED',
                submitAt: new Date().getTime()
            }
        ]).catch(function () { });
        this.startProcess();
    };
    /**
     * List transactions
     *
     * @param {string} status
     * @returns {Promise<any> | Promise<any>}
     */
    AtajoXQueue.prototype.list = function (status) {
        if (status)
            return atajoXDatabase.get(this.tableName, "status='" + status.toUpperCase() + "'");
        return atajoXDatabase.get(this.tableName);
    };
    /**
     * Mark queue as busy
     */
    AtajoXQueue.prototype.queueBusy = function () {
        atajoXDatabase.update(this.tableName, [{ column: "status", value: "QUEUED" }], [{ column: "status", op: "=", value: "BUSY" }]).catch(function () { });
    };
    /**
     * Retry all failed transactions
     */
    AtajoXQueue.prototype.retryFailed = function () {
        atajoXDatabase.update(this.tableName, [{ column: "status", value: "QUEUED" }], [{ column: "status", op: "=", value: "FAILED" }]).catch(function () { });
        this.startProcess();
    };
    /**
     * Clear transactions
     */
    AtajoXQueue.prototype.clear = function () {
        atajoXDatabase.nuke(this.tableName);
        this.stopProcess();
    };
    return AtajoXQueue;
}());
export { AtajoXQueue };
export var atajoXQueue = new AtajoXQueue();
//# sourceMappingURL=queue.js.map