'use strict';
import * as io from "socket.io-client";
import { atajoXConfig } from "../config/config";
import { atajoXEvents } from "../events/events";
var AtajoXSocket = /** @class */ (function () {
    function AtajoXSocket() {
        this.isDomainConnected = false;
    }
    /**
     * Connect to socket network
     *
     * @returns {Promise<void>}
     */
    AtajoXSocket.prototype.connect = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.isConnected()) {
                resolve();
                return;
            }
            var domain = atajoXConfig.STATE.domain;
            var channel = atajoXConfig.STATE.consulConfig.core.dev;
            var socketOptions = atajoXConfig.STATE.socket.options;
            var socketEndpoint = channel.protocol + '://' + channel.host + ':' + channel.port;
            if (_this.socket) {
                _this.socket.destroy();
                delete _this.socket;
            }
            _this.socket = io(socketEndpoint, socketOptions);
            _this.socket.on('connect', function (data) {
                resolve();
                _this.isDomainConnected = true;
                _this.socket.emit('domain:status', { domain: domain });
                atajoXEvents.publish('socket:connect', data);
            });
            _this.socket.on('disconnect', function (data) {
                _this.isDomainConnected = false;
                atajoXEvents.publish('socket:disconnect', data);
            });
            _this.socket.on('client:rx', function (data) {
                atajoXEvents.publish('socket:client:rx', data);
            });
            _this.socket.on('domain:status', function (data) {
                atajoXEvents.publish('socket:status', data);
                if (data.nodes > 0) {
                    _this.isDomainConnected = true;
                }
            });
            _this.socket.on('domain:connect', function (data) {
                atajoXEvents.publish('socket:status', data);
                _this.isDomainConnected = true;
            });
            _this.socket.on('domain:disconnect', function (data) {
                atajoXEvents.publish('socket:status', data);
                if (data.nodes > 0) {
                    _this.isDomainConnected = true;
                }
                else {
                    _this.isDomainConnected = false;
                }
            });
            setTimeout(function () {
                if (!_this.isConnected()) {
                    reject('Connecting to socket timed out');
                }
            }, socketOptions.timeout);
        });
    };
    /**
     * Disconnect from socket
     */
    AtajoXSocket.prototype.disconnect = function () {
        if (this.socket) {
            this.socket.disconnect();
        }
    };
    /**
     * Is connected to socket
     *
     * @returns {boolean}
     */
    AtajoXSocket.prototype.isConnected = function () {
        return (this.socket) ? this.socket.connected : false;
    };
    /**
     * Is domain connected
     *
     * @returns {boolean}
     */
    AtajoXSocket.prototype.domainConnected = function () {
        return this.isDomainConnected;
    };
    /**
     * Emit transaction
     * @param {ApiTransaction} transaction
     */
    AtajoXSocket.prototype.transaction = function (transaction) {
        var tx = {
            version: transaction.version,
            lambda: transaction.lambda,
            domain: atajoXConfig.STATE.domain,
            environment: atajoXConfig.STATE.environment,
            payload: transaction.payload,
            latency: transaction.latency
        };
        this.socket.emit('client:tx', tx);
    };
    return AtajoXSocket;
}());
export { AtajoXSocket };
export var atajoXSocket = new AtajoXSocket();
//# sourceMappingURL=socket.js.map