'use strict';
var request = require('request');
import { atajoXConfig } from '../config/config';
import { atajoXApi } from "../api/api";
var AtajoXTime = /** @class */ (function () {
    function AtajoXTime() {
        this.api = 'http://api.timezonedb.com/v2/get-time-zone?key=AVKJU2HC5L6I&format=json';
        this.retryCounter = 5;
    }
    /**
     * Check if device time is valid
     *
     * @returns {Promise<any>}
     */
    AtajoXTime.prototype.isDeviceTimeValid = function () {
        var _this = this;
        this.retryCounter = 5;
        return new Promise(function (resolve, reject) {
            _this.getTimeFromCore().then(function (data) {
                if (data == null)
                    resolve(false);
                else {
                    console.log("this.config.get");
                    var maxDeviation = atajoXConfig.get('maxTimeDifference', 300);
                    console.log("maxDeviation:" + maxDeviation);
                    var deviceTime = _this.getDeviceTimestamp();
                    var remoteTime = data['timestamp'];
                    var timeDifference = Math.abs(deviceTime - remoteTime);
                    if (timeDifference > maxDeviation) {
                        resolve(false);
                    }
                    else {
                        resolve(true);
                    }
                }
            }, function () {
                resolve(true);
            }).catch(function (error) {
                resolve(true);
            });
        });
    };
    AtajoXTime.prototype.getTimeFromCore = function () {
        return new Promise(function (resolve, reject) {
            atajoXApi.addTransaction('@atajo-time/v1/time/now', {}, { timeout: 180000 }).subscribe(function (result) {
                resolve(result.data);
            }, function (error) { reject(); }, function () { });
        });
    };
    /**
     * Get time from zone
     *
     * @param {string} zone
     * @returns {Promise<any>}
     */
    AtajoXTime.prototype.getTimeFromZone = function (zone) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var query = _this.api + '&by=zone&zone=' + zone;
            console.log('query:' + query);
            request({
                url: query,
                method: 'GET',
                json: true
            }, function (error, response, body) {
                if (error != null) {
                    reject(error);
                }
                else
                    resolve(body);
            });
        });
    };
    /**
     * Get time from location
     *
     * @param {number} lat
     * @param {number} lng
     * @returns {Promise<any>}
     */
    AtajoXTime.prototype.getTimeFromLocation = function (lat, lng) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var query = _this.api + '&by=position&lat=' + lat + '&lng=' + lng;
            request({
                url: query,
                method: 'GET',
                json: true
            }, function (error, response, body) {
                if (error != null)
                    reject(error);
                else
                    resolve(body);
            });
        });
    };
    /**
     * Get device timestamp
     *
     * @returns {number}
     */
    AtajoXTime.prototype.getDeviceTimestamp = function () {
        return new Date().getTime() / 1000;
    };
    return AtajoXTime;
}());
export { AtajoXTime };
export var atajoXTime = new AtajoXTime();
//# sourceMappingURL=time.js.map