import { atajoXConfig } from '../config/config';
import { atajoXDevice } from '../device/device';
import { atajoXEvents } from '../events/events';
var AtajoXUpdate = /** @class */ (function () {
    function AtajoXUpdate() {
        if (!atajoXDevice.isCordova()) {
            console.warn("CORDOVA NOT FOUND -> CODE UPDATES NOT AVAILABLE");
            return;
        }
        if (!window.update) {
            console.warn("CODE UPDATE PLUGIN NOT FOUND -> CODE UPDATES NOT AVAILABLE");
            return;
        }
        var updateConfig = atajoXConfig.get('update');
        this.enabled = updateConfig.enabled;
        this.registerEvents();
    }
    /**
     * Check for new code push updates
     *
     * @param {boolean} restartOnUpdate
     * @param {boolean} persistUpdate
     */
    AtajoXUpdate.prototype.checkForUpdates = function (restartOnUpdate, persistUpdate) {
        if (restartOnUpdate === void 0) { restartOnUpdate = false; }
        if (persistUpdate === void 0) { persistUpdate = true; }
        if (!this.enabled) {
            console.warn('OTA UPDATES NOT AVAILABLE ON THIS DEVICE');
            return;
        }
        if (window.update) {
            var domain = atajoXConfig.get('domain');
            if (domain) {
                window.update.check(domain, restartOnUpdate, persistUpdate);
            }
            else {
                console.warn('NO DOMAIN SET FOR CODE PUSH UPDATES');
            }
        }
    };
    /**
     * Register events
     */
    AtajoXUpdate.prototype.registerEvents = function () {
        var codePushUpdateEvents = [
            'atajo:update:initialized',
            'atajo:update:filesystem:ready',
            'atajo:update:folder:ready',
            'atajo:update:error',
            'atajo:update:download:success',
            'atajo:update:download:error',
            'atajo:update:download:progress',
            'atajo:update:unzip:success',
            'atajo:update:unzip:error',
            'atajo:update:unzip:progress',
            'atajo:update:file:remove:success',
            'atajo:update:file:remove:error',
            'atajo:update:file:get:error'
        ];
        for (var i in codePushUpdateEvents) {
            var codePushEvent = codePushUpdateEvents[i];
            document.addEventListener(codePushEvent, function (event) {
                atajoXEvents.publish(event['name'], event);
            });
        }
    };
    return AtajoXUpdate;
}());
export { AtajoXUpdate };
//# sourceMappingURL=update.js.map